#
# spec file for package python-oslo.privsep
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.privsep
Version:        3.4.0
Release:        1.2
Summary:        OpenStack library for privilege separation
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.privsep
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.privsep/oslo.privsep-3.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-cffi >= 1.14.0
BuildRequires:  python3-eventlet >= 0.21.0
BuildRequires:  python3-greenlet >= 0.4.14
BuildRequires:  python3-msgpack >= 0.6.0
BuildRequires:  python3-oslo.config >= 5.2.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
OpenStack library for privilege separation

%package -n python3-oslo.privsep
Summary:        OpenStack library for privilege separation
Requires:       python3-cffi >= 1.14.0
Requires:       python3-eventlet >= 0.21.0
Requires:       python3-greenlet >= 0.4.14
Requires:       python3-msgpack >= 0.6.0
Requires:       python3-oslo.config >= 5.2.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.log >= 3.36.0
Requires:       python3-oslo.utils >= 3.33.0
%if 0%{?suse_version}
Obsoletes:      python2-oslo.privsep < 2.0.0
%endif

%description -n python3-oslo.privsep
OpenStack library for privilege separation

%package -n python-oslo.privsep-doc
Summary:        oslo.privsep documentation
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.privsep-doc
Documentation for oslo.privsep

%prep
%autosetup -p1 -n oslo.privsep-3.4.0
%py_req_cleanup

%build
%py3_build
# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%py3_install

%check
export PYTHONPATH=.
%{openstack_stestr_run}

%files -n python3-oslo.privsep
%doc README.rst
%license LICENSE
%{_bindir}/privsep-helper
%{python3_sitelib}/oslo_privsep
%{python3_sitelib}/oslo.privsep-*-py?.*.egg-info

%files -n python-oslo.privsep-doc
%doc doc/build/html

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 3.4.0
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/wallaby
  - reno: Update master for unmaintained/xena
  - reno: Update master for unmaintained/victoria
  - reno: Update master for unmaintained/zed
  - Remove old excludes
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 3.3.0
  - Display coverage report
  - add new kernel capabilities
  - Update python classifier in setup.cfg
  - Fix wrong path in coveragerc
  - Bump bandit
  - Update master for stable/2023.2
  - Bump hacking
  - reno: Update master for unmaintained/yoga
  - fix broken links in readme
* Wed Dec 27 2023 cloud-devel@suse.de
- update to version 3.2.0
  - Update master for stable/2023.1
  - Revert "Moves supported python runtimes from version 3.8 to 3.10"
  - Moves supported python runtimes from version 3.8 to 3.10
  - setgid should be called before setuid
  - Imported Translations from Zanata
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 3.1.0
  - Add Python3 antelope unit tests
  - Setup logging without fixing evenlet logging
  - Update master for stable/zed
* Sun Oct  2 2022 cloud-devel@suse.de
- update to version 3.0.1
  - Remove logic for Python < 3.8
  - Drop python3.6/3.7 support in testing runtime
* Tue May 24 2022 Dirk Müller <dmueller@suse.com>
- remove unneded mock dependency
* Fri May 13 2022 cloud-devel@suse.de
- update to version 2.8.0
  - Fix formatting of release list
  - Add note explaining max_buffer_size value
  - Update master for stable/yoga
  - Remove unnecessary unicode prefixes
  - Bump max_buffer_size for Deserializer
  - Add Python3 yoga unit tests
  - Add Python3 zed unit tests
  - Remove six
  - Update master for stable/xena
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.6.2
  - Fix requirements issues.
  - Allow finer grained log levels
  - Changed minversion in tox to 3.18.0
  - Use TOX_CONSTRAINTS_FILE
  - Add Python3 xena unit tests
  - Add except path with exception debug to send_recv
  - Add timeout to PrivContext and entrypoint_with_timeout decorator
  - Use py3 as the default runtime for tox
  - setup.cfg: Replace dashes with underscores
  - Upgrade the pre-commit-hooks version
  - Update master for stable/wallaby
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.5.0
  - Update master for stable/victoria
  - Add Python3 wallaby unit tests
  - Adding pre-commit
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.4.0
  - Add release notes links to doc index
  - Bump default tox env from py37 to py38
  - Remove translation sections from setup.cfg
  - Add py38 package metadata
  - Replace assertItemsEqual with assertCountEqual
  - Undo the eventlet monkey patch for the privileged daemon
  - [goal] Migrate testing to ubuntu focal
  - Align contributing doc with oslo's policy
  - Remove the unused coding style modules
  - Fix pygments style
  - Add Python3 victoria unit tests
  - Fix hacking min version to 3.0.1
  - Switch to newer openstackdocstheme and reno versions
  - Bump bandit version
  - Update master for stable/ussuri
* Tue May 12 2020 cloud-devel@suse.de
- removed 0001-Disable-logger-validation-during-unit-testing.patch
- update to version 2.1.1
  - tox: Add missing 'deps' for releasenotes testenv
  - Switch to Ussuri jobs
  - Bump the openstackdocstheme extension to 1.20
  - Add functional tests
  - trivial: Cleanup Sphinx config file, setup.cfg
  - Add lock around channel creation
  - Update hacking for Python3
  - Use unittest.mock instead of third party mock
  - Update the constraints url
  - tox: Trivial cleanup
  - [ussuri][goal] Drop python 2.7 support and testing
  - remove outdated header
  - Disable logger validation during unit testing
  - Bring sanity to lower-constraints
  - Update master for stable/train
  - Make compatible with msgpack 1.0.0
  - tox: Keeping going with docs
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Tue Mar 17 2020 cloud-devel@suse.de
- added 0001-Disable-logger-validation-during-unit-testing.patch
* Fri Mar 13 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.33.3
  - Pass correct arguments to six.reraise
  - Cap Bandit below 1.6.0 and update Sphinx requirement
  - OpenDev Migration Patch
  - Convert dict keys received in _ClientChannel from byte to str
  - Move doc related modules to doc/requirements.txt
  - Replace git.openstack.org URLs with opendev.org URLs
  - Add more usage documentation
  - Self-resetting PrivContext
  - Add sample_default for thread_pool_size Opt
  - Update master for stable/stein
  - Add Python 3 Train unit tests
  - Reno for SIGHUP fix
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.32.1
  - Remove PyPI downloads
  - Switch to stestr
  - Update mailinglist from dev to discuss
  - Use template for lower-constraints
  - import zuul job settings from project-config
  - Add that 'Release Notes' in README
  - Add futures as a requirement for Python 2
  - Added example blogposts
  - Update reno for stable/rocky
  - Don't quote {posargs} in tox.ini
  - add python 3.6 unit test job
  - add lib-forward-testing-python3 test job
  - Expose privsep options for config-generator
  - Set unicode_errors handler to 'surrogateescape' in msgpack
  - Trivial: Update pypi url to new url
  - Replace assertRaisesRegexp with assertRaisesRegex
  - Avoids calling ffi.dlopen(None) on Windows
  - fix tox python3 overrides
  - Update hacking version
  - Clean up .gitignore references to personal tools
  - Use threads to process target function
  - add python 3.7 unit test job
* Wed Mar  6 2019 cloud-devel@suse.de
- update to version 1.29.2
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Switch to stestr
  - Avoids calling ffi.dlopen(None) on Windows
  - Update .gitreview for stable/rocky
  - import zuul job settings from project-config
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.29.0
  - set default python to python3
  - Update reno for stable/queens
  - Update links in README
  - Skip unit tests in bandit scan
  - fix lower constraints and uncap eventlet
  - Imported Translations from Zanata
  - Updated from global requirements
  - add lower-constraints job
  - msgpack-python has been renamed to msgpack
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.27.0 (bsc#1078607)
  - Update .gitreview for stable/queens
  - msgpack-python has been renamed to msgpack
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.26.0 (bsc#1078607)
  - Remove -U from pip install
  - Expose caps values/names as int enum
  - Update reno for stable/pike
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Avoid tox_install.sh for constraints support
  - add bandit to pep8 job
  - Updated from global requirements
  - Update capabilities from current kernel source
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.22.0
  - Preserve all LogRecord fields from privileged side
  - Remove log translations
  - Update URLs in documents according to document migration
  - Use iterable object for 'args' in log record
  - rearrange existing documentation to follow the new standard layout
  - add sphinx instructions to build API reference docs
  - [Fix gate]Update test requirement
  - Enable some off-by-default checks
  - Remove references to Python 3.4
  - switch from oslosphinx to openstackdocstheme
  - pbr.version.VersionInfo needs package name (oslo.xyz and not oslo_xyz)
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - Add test to verify log record can be formatted
  - Using assertIsNone(xxx) instead of assertEqual(None, xxx)
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.16.0:
  - Don't use deprecated method logger.warn
  - Update reno for stable/newton
  - modify the home-page info with the developer documentation
  - Updated from global requirements
  - Add Constraints support
  - Ignore timeout error when receiving message from sockect
  - Show team and repo badges on README
  - Report underlying integer for unknown capabilities
  - Imported Translations from Zanata
  - Enable release notes translation
  - Add Python 3.5 classifier and venv
  - Deal with CONF.config_dir correctly
- Remove 0001-Deal-with-CONF.config_dir-correctly.patch . Applied upstream.
* Fri Dec 23 2016 tbechtold@suse.com
- update to version 1.13.1:
  * Update .gitreview for stable/newton
  * [Backport] Ignore timeout error when receiving message
* Fri Dec  2 2016 tbechtold@suse.com
- Add 0001-Deal-with-CONF.config_dir-correctly.patch
* Fri Oct 14 2016 tbechtold@suse.com
- switch to stable/newton tarball in _service
* Tue Aug 30 2016 tbechtold@suse.com
- update to version 1.13.0
  * Fixes unit tests on Windows.
  * Add reno for release notes management
  * Use default value for undefined caps in fmt_caps
  * Updated from global requirements
  * More sophisticated logging on privileged side
* Wed Aug 10 2016 tbechtold@suse.com
- update to 1.11.0:
  * Updated from global requirements
  * Provide way to "initialise" oslo.privsep
  * PrivContext: Sets client_mode to False on Windows
  * Imported Translations from Zanata
  * Drop python3.3 support in classifier
  * Remove unused py27 socketpair/makefile workaround
  * Remove direct dependency on babel
  * Switch to msgpack for serialization
- Update _service and switch to upstream spec template
* Mon Apr  4 2016 tbechtold@suse.com
- Initial packaging (version 1.4.0)
